@@ -9,7 +9,7 @@
 project = 'Literate Sphinx'
 copyright = '2023, Hubert Chathi'
 author = 'Hubert Chathi'
-release = '0.1.0'
+release = '0.1.1'
 
 # -- General configuration ---------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration
@@ -35,5 +35,8 @@ html_theme = 'alabaster'
 html_static_path = []
 
 html_theme_options = {
-    'description': 'A literate programming extension for Sphinx'
+    'description': 'A literate programming extension for Sphinx',
+    'extra_nav_links': {
+        'Source': 'https://gitlab.com/uhoreg/literate-sphinx'
+    }
 }
